==> negenes_1.0-12.tar.gz: negenes/README.md <==
## R/negenes

[![Build Status](https://travis-ci.org/kbroman/negenes.svg?branch=master)](https://travis-ci.org/kbroman/negenes)
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/negenes)](https://cran.r-project.org/package=negenes)

[Karl W Broman](https://kbroman.org)

[R/negenes](https://github.com/kbroman/negenes) is an R package for estimating the number of essential genes
in a genome on the basis of data from a random transposon mutagenesis
experiment, through the use of a Gibbs sampler.

See the following:

- Lamichhane et al. (2003) [A post-genomic method for predicting
  essential genes at subsaturation levels of mutagenesis: application
  to Mycobacterium tuberculosis](https://www.biostat.wisc.edu/~kbroman/publications/mutagenesis.pdf).
  Proc Natl Acad Sci USA 100:7213-7218
  ([doi:10.1073/pnas.1231432100](https://doi.org/10.1073/pnas.1231432100))

- Blades NJ, Broman KW (2002)
  [Estimating the number of essential genes in a genome by random transposon mutagenesis](https://www.biostat.wisc.edu/~kbroman/publications/ms0220.pdf).
  Technical Report MS02-20, Department of Biostatistics, Johns Hopkins University, Baltimore, MD


### License

This package is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License, version 3, as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful, but
without any warranty; without even the implied warranty of
merchantability or fitness for a particular purpose.  See the GNU
General Public License for more details.

A copy of the GNU General Public License, version 3, is available at
<https://www.r-project.org/Licenses/GPL-3>

==> negenes_1.4.tar.gz: negenes/README.md <==
## R/negenes

[![R-CMD-check](https://github.com/kbroman/negenes/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/kbroman/negenes/actions/workflows/R-CMD-check.yaml)
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/negenes)](https://cran.r-project.org/package=negenes)
[![zenodo DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3361121.svg)](https://doi.org/10.5281/zenodo.3361121)

[Karl W Broman](https://kbroman.org)

[R/negenes](https://github.com/kbroman/negenes) is an R package for estimating the number of essential genes
in a genome on the basis of data from a random transposon mutagenesis
experiment, through the use of a Gibbs sampler.

See the following:

- Lamichhane et al. (2003) [A post-genomic method for predicting
  essential genes at subsaturation levels of mutagenesis: application
  to Mycobacterium tuberculosis](https://www.biostat.wisc.edu/~kbroman/publications/mutagenesis.pdf).
  Proc Natl Acad Sci USA 100:7213-7218
  ([doi:10.1073/pnas.1231432100](https://doi.org/10.1073/pnas.1231432100))

- Blades NJ, Broman KW (2002)
  [Estimating the number of essential genes in a genome by random transposon mutagenesis](https://www.biostat.wisc.edu/~kbroman/publications/ms0220.pdf).
  Technical Report MS02-20, Department of Biostatistics, Johns Hopkins University, Baltimore, MD


### License

This package is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License, version 3, as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful, but
without any warranty; without even the implied warranty of
merchantability or fitness for a particular purpose.  See the GNU
General Public License for more details.

A copy of the GNU General Public License, version 3, is available at
<https://www.r-project.org/Licenses/GPL-3>
